import Gio from 'gi://Gio';
import Gtk from 'gi://Gtk';
import Adw from 'gi://Adw';

import {ExtensionPreferences} from 'resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js';

export default class SystemSoftwareInfoPreferences extends ExtensionPreferences {
    fillPreferencesWindow(window) {
        window._settings = this.getSettings('org.gnome.shell.extensions.system-software-info');
        const page = new Adw.PreferencesPage({
            title: 'System Software Info - Preferences',
            icon_name: 'dialogrmation-symbolic',
        });
        window.add(page);

        const group_items = new Adw.PreferencesGroup({
            title: 'Info',
        });
        page.add(group_items);
        
        const row_os = new Adw.SwitchRow({
            title: 'Show OS',
        });
        group_items.add(row_os);
        window._settings.bind('show-os', row_os, 'active', Gio.SettingsBindFlags.DEFAULT);
        
        let os_style_settings = new Gtk.StringList();        
        os_style_settings.append('Extended', '0');
        os_style_settings.append('Compact', '1');
        const row_os_style = new Adw.ComboRow({
            title: "OS info style",
            model: os_style_settings,
            selected: window._settings.get_enum('os-style')
        });        
        group_items.add(row_os_style);
        row_os_style.connect('notify::selected', (widget) => {
            window._settings.set_enum('os-style', widget.selected);
        });        
        
        const row_kernel = new Adw.SwitchRow({
            title: 'Show kernel',
        });
        group_items.add(row_kernel);
        window._settings.bind('show-kernel', row_kernel, 'active', Gio.SettingsBindFlags.DEFAULT);
        
        let kernel_style_settings = new Gtk.StringList();        
        kernel_style_settings.append('Extended', '0');
        kernel_style_settings.append('Compact 1', '1');
        kernel_style_settings.append('Compact 2', '2');
        const row_kernel_style = new Adw.ComboRow({
            title: "Kernel style",
            model: kernel_style_settings,
            selected: window._settings.get_enum('kernel-style')
        });        
        group_items.add(row_kernel_style);
        row_kernel_style.connect('notify::selected', (widget) => {
            window._settings.set_enum('kernel-style', widget.selected);
        });
        
        const row_shell = new Adw.SwitchRow({
            title: 'Show shell',
        });
        group_items.add(row_shell);
        window._settings.bind('show-shell', row_shell, 'active', Gio.SettingsBindFlags.DEFAULT);    
        
        let shell_style_settings = new Gtk.StringList();
        shell_style_settings.append('Extended', 'GNOME Shell');
        shell_style_settings.append('Compact', 'GNOME');
        const row_shell_style = new Adw.ComboRow({
            title: "Shell style",
            model: shell_style_settings,
            selected: window._settings.get_enum('shell-style')
        });        
        group_items.add(row_shell_style);
        row_shell_style.connect('notify::selected', (widget) => {
            window._settings.set_enum('shell-style', widget.selected);
        });
        
        let separator_style_settings = new Gtk.StringList();        
        separator_style_settings.append('Dot', '0');
        separator_style_settings.append('Dash', '1');
        separator_style_settings.append('Long dash', '2');
        separator_style_settings.append('Pipe', '3');
        separator_style_settings.append('Comma', '4');
        const row_separator_style = new Adw.ComboRow({
            title: "Separator style",
            model: separator_style_settings,
            selected: window._settings.get_enum('separator-style')
        });        
        group_items.add(row_separator_style);
        row_separator_style.connect('notify::selected', (widget) => {
            window._settings.set_enum('separator-style', widget.selected);
        });
        
        const adjustment_separator_width = new Gtk.Adjustment({
            lower: 1,
            upper: 8,
            step_increment: 1,
        });
        const row_separator_width = new Adw.SpinRow({
            title: 'Separator width',
            adjustment: adjustment_separator_width,
        });
        group_items.add(row_separator_width);
        window._settings.bind('separator-width', row_separator_width, 'value', Gio.SettingsBindFlags.DEFAULT);
        
        const position_group_items = new Adw.PreferencesGroup({
            title: 'Layout',
        });
        page.add(position_group_items);
        
        let position_box_settings = new Gtk.StringList();        
        position_box_settings.append('Left', '0');
        position_box_settings.append('Center', '1');
        position_box_settings.append('Right', '2');
        const row_position_box = new Adw.ComboRow({
            title: "Position",
            model: position_box_settings,
            selected: window._settings.get_enum('position-box')
        });        
        position_group_items.add(row_position_box);
        row_position_box.connect('notify::selected', (widget) => {
            window._settings.set_enum('position-box', widget.selected);
        });
        
        const adjustment_position_offset = new Gtk.Adjustment({
            lower: 0,
            upper: 20,
            step_increment: 1,
        });
        const row_position_offset = new Adw.SpinRow({
            title: 'Offset',
            adjustment: adjustment_position_offset,
        });
        position_group_items.add(row_position_offset);
        window._settings.bind('position-offset', row_position_offset, 'value', Gio.SettingsBindFlags.DEFAULT);
    }
}
